@@ -8,6 +8,8 @@ import os
 from functools import wraps
 from typing import Dict
 
+import click
+
 logger = logging.getLogger(__name__)
 
 
@@ -30,19 +32,18 @@ def kwargs_to_dataclass(data_class):
     return _kwargs_to_dataclass
 
 
-def load_context(params) -> Dict[str, any]:
+def default_from_context(key: str):
     """
-    Loads a configuration file and returns the content.
+    Allows for a default option to reference the Click Context obj object for a default value.
 
-    :param params: The root CLI commands params object.
-    :return: The loaded configuration object.
-    :raises: FileNotFoundError if configuration file does not exist.
+    :param key: The name of the value to reference.
+    :return: The context as default custom option class.
     """
-    config_file = params.config_file
 
-    if os.path.exists(config_file):
-        with open(config_file) as fh:
-            return yaml.safe_load(fh)
+    class OptionDefaultFromContext(click.Option):
 
-    else:
-        raise FileNotFoundError(f"Could not find configuration file: '{config_file}'")
+        def get_default(self, ctx):
+            self.default = ctx.obj[key]
+            return super(OptionDefaultFromContext, self).get_default(ctx)
+
+    return OptionDefaultFromContext
