@@ -7,6 +7,7 @@ import logging
 from functools import wraps
 
 import colorama
+from alive_progress import config_handler
 
 logger = logging.getLogger(__name__)
 
@@ -23,6 +24,23 @@ def init_colorama(func):
     return init_colorama_wrapper
 
 
+def init_progress_bars(func):
+    """Initialises the progress bar configuration."""
+
+    @wraps(func)
+    def init_progress_bars_wrapper(*args, **kwargs):
+        config_handler.set_global(
+            title_length=40,
+            spinner="classic",
+            unknown="classic",
+            bar="classic"
+        )
+
+        return func(*args, **kwargs)
+
+    return init_progress_bars_wrapper
+
+
 def make_header(title: str, char: str = "=") -> str:
     """
     Returns a uniform header format to use in the CLI output.
