@@ -12,21 +12,31 @@ logger = logging.getLogger(__name__)
 class Path:
 
     @staticmethod
-    def project_root():
+    def project_root() -> str:
         """Returns the root project path."""
         current_dir = os.path.dirname(__file__)
 
-        for i in range(2):
+        for _ in range(2):
             current_dir = os.path.dirname(current_dir)
 
         return current_dir
 
     @staticmethod
-    def src_root():
+    def src_root() -> str:
         """Returns the src root path."""
         return os.path.join(Path.project_root(), "src")
 
     @staticmethod
-    def db():
+    def db_dir() -> str:
         """Returns the path to the DB file."""
-        return os.path.join(Path.project_root(), "db", "db.json")
+        return os.path.join(Path.project_root(), "db")
+
+    @staticmethod
+    def db() -> str:
+        """Returns the path to the DB file."""
+        return os.path.join(Path.db_dir(), "db.json")
+
+    @staticmethod
+    def isic_metadata() -> str:
+        """Returns the path to the ISIC metadata CSV file."""
+        return os.path.join(Path.db_dir(), "isic_metadata.csv")
