@@ -7,13 +7,13 @@ import pytest
 import logging
 
 from click.testing import CliRunner
-from sla_cli.entry import cli
+from sla_cli.entry import cli as _cli
 
 
 @pytest.fixture(autouse=True)
 def set_log_level(caplog):
     """Set the log level for the test session."""
-    caplog.set_level(logging.INFO)
+    caplog.set_level(logging.DEBUG)
 
 
 @pytest.fixture
@@ -25,4 +25,4 @@ def cli_runner() -> CliRunner:
 @pytest.fixture
 def cli() -> callable:
     """Returns the root CLI callable command."""
-    return cli
+    return _cli
